%% Create an elliptic LPF for a test of creating an S-Parameter block
%  from frequency domain measurements, and incorporating this in the
%  SimScape  environment. 
%  The objective is to model a "channel", in this case a filter, 
%  just once, and then be able to adjust source and load impedances 
%  without regenerating the entire channel model. 
% Copyright 2006-2015 The Mathworks, Inc.
% Dick Benson
clear
clc
close all
% Normalized values from table in Zverev PP 220  
% plus normalized load Zl value
%       L1      L2    C2    L3    L4      C4    L5   Zl
LCvec=[1.275,0.2287,1.105,1.752,0.6786,0.7858,0.978, 1];
Freq=[1:.2:100]*1e6; 
fc = 30e6;  % cutoff freq
Zo = 50;  
Q=1000;
[lpf1,LCvalues,Tf]=ellip_lpf_func(LCvec,Freq,fc,Zo,Q);
hplot = plot(lpf1,'s21'); % 
[X, Freq] = extract(lpf1,'S_parameters',50);


%% Create Rational Function Representation for 4 S parameters
% and plot the fit with input data for a sanity check
% Note that the rational fitting parameters need to be adjusted on a case
% by case basis.  Sorry, there is no GUI .... yet! 
FittingTolerance = -35;   % Rational fitting tolerance in dB 
DelayFactor = 0.0;        % Delay factor, set to zero if there is no never ending linear phase shift 
npoles      = 5;         % Use this number of poles 
for k=1:2
    for n=1:2

RationalFuncModel(k,n) = ...
    rationalfit(Freq,X(k,n,:),FittingTolerance,'DelayFactor',DelayFactor,'TendsToZero',false,'NPoles',npoles,'WaitBar',true);


nPoles = length(RationalFuncModel(k,n).A);

% Plot freq responses
figure;  % a new figure for each of the s-parameter fit results
PlotFreq = Freq;
RespAtPlotFrequency = freqresp(RationalFuncModel(k,n), PlotFreq);
subplot(2,1,1); plot(Freq*1.e-9, 20*log10(abs(squeeze(X(k,n,:)))), 'r', ...
    PlotFreq*1.e-9, 20*log10(abs(RespAtPlotFrequency)), 'b--', 'LineWidth', 2);
title(['Rational Fitting S(', num2str(k),' ',num2str(n),')'],'FontSize', 12);
axis([0,PlotFreq(end)*1e-9,-60,10])
ylabel('Magnitude (decibels)'); xlabel('Frequency (GHz)');
legend('Original', 'Fitting result');
subplot(2,1,2); plot(Freq*1.e-9, unwrap(angle(squeeze(X(k,n,:))))*180/pi, 'r', ...
    PlotFreq*1.e-9, unwrap(angle(RespAtPlotFrequency))*180/pi, 'b--', 'LineWidth', 2);
ylabel('Phase in degrees'); xlabel('Frequency (GHz)');
legend('Original', 'Fitting result');
set(gcf,'Name','MATLAB Model Results');
drawnow
    end
end
save Ellip_Model RationalFuncModel
%% Simulate in Simulink / SimScape

ModelName = 'Elliptic_Filter_SS_Model';
open_system(ModelName);
% sim(ModelName)
