function build_simulink_model(RationalFuncModel)
% Dick Benson
% This mcode works in conjunction with the block in the simulink_rational_model.mdl example. 
% Rearrange order of poles and residues

%global rat_num
%global rat_den


nPoles = length(RationalFuncModel.A);
OriginalA = RationalFuncModel.A; OriginalC = RationalFuncModel.C;
A = zeros(length(OriginalA), 1); C = zeros(length(OriginalC), 1);
kk = 1;
for k = 1:nPoles
    if isnan(OriginalA(k))
        continue
    elseif ~isreal(OriginalA(k))
        % Complex poles and residues
        pos = find(OriginalA == conj(OriginalA(k)), 1);
        OriginalA(pos) = NaN; OriginalC(pos) = NaN;
    end
    A(kk) = OriginalA(k); C(kk) = OriginalC(k); kk = kk + 1;
end
A = A(1:kk-1); C = C(1:kk-1);
% Get the Numerators and Denominators of the Laplace Transform S-Domain Filters
% Convert the vectors of real and complex poles and residues of the rational function model 
% into real numerators and denominators of Laplace Transform S-domain filters. 

nA = length(A); 
rat_den = cell(nA, 1); 
rat_num = cell(nA, 1);


for k = 1:nA
    if isreal(A(k))     % Real poles
        rat_num{k} = C(k); rat_den{k} = [1, -A(k)];
    else                % Complex poles
        real_a = real(A(k)); imag_a = imag(A(k));
        real_c = real(C(k)); imag_c = imag(C(k));
        rat_num{k} = [2*real_c, -2*(real_a*real_c+imag_a*imag_c)];
        rat_den{k} = [1, -2*real_a, real_a^2+imag_a^2];
    end
end
xfer_blocks = length(rat_den);
rtsys        = gcb;   % Block become "current" when its initialize function is called.
Xfer_stages  = find_system(rtsys,'RegExp','on','lookUnderMasks', 'all', 'FollowLinks','on','BlockType','TransferFcn'); % note there are no spaces in the TransferFcn !!!
L_stage = length(Xfer_stages);
   %In_port      = find_system(rtsys,'lookUnderMasks', 'all','BlockType','Inport');
   %Out_port     = find_system(rtsys,'lookUnderMasks', 'all','BlockType','Outport');
   Gain_stage   = find_system(rtsys,'lookUnderMasks', 'all', 'BlockType','Gain');
   Sum_stages   = find_system(rtsys,'lookUnderMasks', 'all', 'BlockType','Sum');
   Delay_stage  = find_system(rtsys,'lookUnderMasks', 'all', 'BlockType','TransportDelay');

if L_stage ~=nA
  %  Delete existing elements (Brute Force!) 
   disp('Programatically Building Rational Transfer Function Block ') 
  % need to rebuild the model
   if L_stage >1
       for k=2:L_stage
           % need to go in order that is in Xfer_stages
           s = Xfer_stages{k};
           p = findstr('_',s);
           p_last = p(end);
           stage=(s((p_last+1):end));
           delete_line(rtsys, 'In1/1' , ['stage_',stage,'/1']);
           delete_line(rtsys,['stage_',stage,'/1'],['Combiner/',stage]);
           % disp(['Deleting ',['stage_',stage]])
           delete_block(Xfer_stages{k}); 
           drawnow;
       end;
   end;

   
   % set direct feedthrough gain
   set_param(Gain_stage{1},'Gain',sprintf('%30d',RationalFuncModel.D)); % the gain value
   % set delay element value
   % get_param(Delay_stage{1},'ObjectParameters')
  
     
   add_pos=get_param(Sum_stages{1},'Position')
   set_param(Delay_stage{1},'Delay',sprintf('%30d',RationalFuncModel.Delay)); % delay value
   set_param(Delay_stage{1},'BufferSize','1024'); % this needs more work ##############

   
   
   
   % Rebuild structure
   % setup combiner (summer) to correct number of inputs
   % Set up the Combiner
   % get_param(Sum_stages{2},'ObjectParameters')
   % get_param(Sum_stages{2},'Inputs')
   s='+';
   for k=2:xfer_blocks
       s=[s,'+'];
   end;
   set_param(Sum_stages{2},'Inputs',s);  % sets number of inputs to Combiner block

   % add Xfer Fcn blocks
   % get_param(Xfer_stages{1},'ObjectParameters')
   xfer_pos=get_param(Xfer_stages{1},'Position');
   % name_1 = get_param(Xfer_stages{1},'Name');
   nstring = ['[',sprintf('%35.5f',rat_num{1}),']'];
   dstring = ['[',sprintf('%35.5f',rat_den{1}),']'];
   set_param(Xfer_stages{1},'Numerator',nstring,'Denominator',dstring);
   src = Xfer_stages{1};  % use as reference block
   for k=2:xfer_blocks
       dst=[src(1:(end-1)),int2str(k)];
       nstring = ['[',sprintf('%35.5f',rat_num{k}),']'];
       dstring = ['[',sprintf('%35.5f',rat_den{k}),']'];
       add_block(src,dst,'Position',[xfer_pos(1) ,xfer_pos(2)+(k-1)*50, xfer_pos(3) ,xfer_pos(4)+(k-1)*50],'Numerator',nstring,'Denominator',dstring);
       add_line(rtsys,'In1/1',['stage_',int2str(k),'/1'],'autorouting','on'); % hook up inputs
       add_line(rtsys,['stage_',int2str(k),'/1'],['Combiner/',int2str(k)],'autorouting','on'); % and outputs 
    end;

else
    % Order has not changed, but coefficients may have.
    disp('No programatic build is required, but coefficients are being updated.')
    % set direct feedthrough gain
    set_param(Gain_stage{1},'Gain',sprintf('%30d',RationalFuncModel.D)); % the gain value
    
    
    % set delay element value
    add_pos=get_param(Sum_stages{1},'Position')
    %add_pos =   475    26   505    59
    %delay_pos=  570    30   600    60

    delay_pos=get_param(Delay_stage{1},'Position')
    if RationalFuncModel.Delay==0
       %delete_block(Delay_stage{1});
       % delete_line(rtsys,[Delay_stage{1}],'Out1/1');
    else
       set_param(Delay_stage{1},'Delay',sprintf('%30d',RationalFuncModel.Delay)); % delay value
       set_param(Delay_stage{1},'BufferSize','1024'); % this needs more work ##############
    end;
    src = Xfer_stages{1};  % use as reference block
    for k=1:xfer_blocks
       dst=[src(1:(end-1)),int2str(k)];
       nstring = ['[',sprintf('%35.5f',rat_num{k}),']'];
       dstring = ['[',sprintf('%35.5f',rat_den{k}),']'];
       set_param(dst,'Numerator',nstring,'Denominator',dstring); drawnow;
    end;
        
end;
if RationalFuncModel.Delay==0
   clc; % clear command window warning 
   drawnow;
end;
    
% end of function
